/**********************************************************************
ID: autoaccept.c

Copyright 2001, Bulent Yilmaz

Part of Microbrew MicroSieve
USENET SPAM filter

http://www.microbrew.org/products/usieve.html


MicroSieve is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

MicroSieve is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with MicroSieve; if not, write to the Free Software Foundation, Inc.,
59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

**********************************************************************/

#include "autoaccept.h"

#if PATH_MATCH

static regex_t matching_path;
static int matching_path_compiled=0;

int pathmatch(char *msgpath) {

    char *pathregex;
#if TESTOUTPUT
    FILE *temphandle;
#endif

#if TESTOUTPUT
    cflog("pathmatch: About to see if regex_t is compiled");
#endif
    
    if(!matching_path_compiled) {
#if TESTOUTPUT
      cflog("pathmatch: About to compile regex_t");
#endif
      if((pathregex=getautoacceptregex()) != 0) {
        if(!regcomp(&matching_path,
                    pathregex,
                    REG_EXTENDED|REG_NOSUB|REG_NEWLINE
                   )) {
#if TESTOUTPUT
            cflog("pathmatch: Regexp loaded");
#endif
	    free(pathregex);
            matching_path_compiled=1;
        } else {
            free(pathregex);
            return -1;    
        }
      }
    }

#if TESTOUTPUT
    temphandle=getloghandle();
    fprintf(temphandle, "About to compare %s to REGEXP %s\n", msgpath, PATH_REGEX);
    fflush(temphandle);
#endif

    if(!regexec(&matching_path,msgpath,0,NULL,REG_NEWLINE)) {
#if TESTOUTPUT
	cflog("pathmatch: Path matched PATH_REGEX");
#endif
	return 1;
    }
    
    return 0;
}

void freepathmatchregex() {

    if(matching_path_compiled) {
        regfree(&matching_path);
        
        matching_path_compiled=0;
    }
    
}

#endif /* PATH_MATCH */